#
# spec file for package python-django-perf-rec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-perf-rec
Version:        4.26.0
Release:        1.1
Summary:        Keep detailed records of the performance of your Django code
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/adamchainz/django-perf-rec
Source:         https://github.com/adamchainz/django-perf-rec/archive/refs/tags/%{version}.tar.gz#/django-perf-rec-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 3.2
Requires:       python-PyYAML
Requires:       python-sqlparse >= 0.4.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 3.2}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module sqlparse >= 0.4.0}
# /SECTION
%python_subpackages

%description
Keep detailed records of the performance of your Django code.

%prep
%setup -q -n django-perf-rec-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=tests.settings
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Jul  8 2024 Dirk Müller <dmueller@suse.com>
- update to 4.26.0:
  * Support Django 5.1.
  * Optimize sql_fingerprint() a bit, yielding ~2%% savings.
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 4.25.0:
  * Support Django 5.0.
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 4.24.0:
  * Drop Python 3.7 support.
* Mon Jun 26 2023 Markéta Machová <mmachova@suse.com>
- Update to 4.23.0
  * Support Django from 3.2 to 4.2.
  * Support Python from 3.7 to 3.12.
  * Stop distributing tests to reduce package size.
  * Re-add simplification of SQL IN clauses to always use (...).
  * Support arbitrary collections of keys being passed to Django cache operations.
  * Add type hints.
  * Add new MODE option, 'overwrite', which creates or updates missing records silently.
  * Fix compatibility with sqlparse 0.4.4+.
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Mon Jan  4 2021 Markéta Machová <mmachova@suse.com>
- Update to 4.11.0
  * Drop Python 3.5 support, support Python 3.9.
  * Remove ORM patching.
  * Drop Django 2.0 and 2.1 support.
  * Upgrade for sqlparse 0.4.0+. This required changing how SQL lists
    of one element are simplified, e.g. IN (1) will now be simplified
    to IN (#) instead of IN (...). You should regenerate your
    performance record files to match.
* Sat Oct 10 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Mon Jun 29 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v4.7.0
